sdk_service/chat_sdk_define library

Classes

ChatAreaCode
ChatClient
The ChatClient class, which is the entry point of the Chat SDK. With this class, you can log in, log out, and access other functionalities such as group and chatroom.
ChatCmdMessageBody
The command message body.
ChatContact
ChatContactChangeEvent
ChatContactEventHandler
The contact event handler.
ChatContactManager
The contact manager class, which manages chat contacts such as adding, deleting, retrieving, and modifying contacts.
ChatConversation
The conversation class, indicating a one-to-one chat, a group chat, or a conversation chat. It contains the messages that are sent and received within the conversation.
ChatCursorResult<T>
The ChatCursorResult class, which specifies the cursor from which to query results. When querying using this class, the SDK returns the queried instance and the cursor.
ChatCustomMessageBody
The custom message body.
ChatDeviceInfo
The ChatDeviceInfo class, which contains the multi-device information.
ChatDownloadCallback
The group shared download callback.
ChatEventHandler
The chat event handler.
ChatFileMessageBody
The base class of file messages.
ChatGroup
The ChatGroup class, which contains the information of the chat group.
ChatGroupChangeEvent
ChatGroupEventHandler
The group event handler.
ChatGroupInfo
The class that defines basic information of chat groups.
ChatGroupManager
The group manager class, which manages group creation and deletion, user joining and exiting the group, etc.
ChatGroupMessageAck
The class for group message read receipts.
ChatGroupOptions
The group options to be configured when the chat group is created.
ChatGroupSharedFile
The ChatGroupSharedFile class, which manages the chat group shared files.
ChatImageMessageBody
The image message body class.
ChatLocationMessageBody
The location message class.
ChatMessage
The message class.
ChatMessageBody
ChatMessageEvent
The message status event class. During message delivery, the message ID will be changed from a local uuid to a global unique ID that is generated by the server to uniquely identify a message on all devices using the SDK. This API should be implemented in the chat page widget to listen for message status changes.
ChatMessageReaction
The message Reaction instance class, which has the following attributes: Reaction: The message Reaction. UserCount: The count of users that added the Reaction. UserList: The list of users that added the Reaction. isAddedBySelf: Whether the current user added this Reaction.
ChatMessageReactionEvent
The message reaction change event class.
ChatMethodKeys
ChatMultiDeviceEventHandler
The multi-device event handler. Listens for the callback for the current user's actions on other devices, including contact changes, group changes, and thread changes.
ChatOptions
The ChatOptions class, which contains the settings of the Chat SDK.
ChatPageResult<T>
The ChatPageResult class, which is returned when calling the methods that fetch data by pagination. The SDK also returns the number of remaining pages and the data count of the next page. If the dada count is less than the count you set, there is no more data on server.
ChatPresence
The presence property class that contains presence properties, including the publisher's user ID and current presence state, and the platform used by the online device, as well as the presence's extension information, update time, and subscription expiration time.
ChatPresenceEventHandler
The presence event handler.
ChatPresenceManager
The Manager that defines how to manage presence states.
ChatPresenceStatusDetail
The presence details, including the platform used by the publisher's current online device and the current presence state.
ChatPushConfig
The push configuration class, which contains the push configuration information, such as the push style.
ChatPushConfigs
The push configuration class.
ChatPushManager
The message push configuration options.
ChatRoomEvent
ChatRoomManager
The chat room manager class, which manages user joining and exiting the chat room, retrieving the chat room list, and managing member privileges. The sample code for joining a chat room:
ChatSilentModeTime
For offline push DND time class.
ChatTextMessageBody
The text message class.
ChatThreadManager
The chat thread manager class.
ChatTranslateLanguage
The translation language class, which contains the information of the translation languages.
ChatUserInfo
The ChatUserInfo class, which contains the user attributes, such as the nickname, description, and avatar.
ChatUserInfoManager
The user attribute manager class, which gets and sets the user attributes.
ChatVideoMessageBody
The video message body class.
ChatVoiceMessageBody
The voice message body class.
ConversationFetchOptions
The conversation filter class.
ExtSettings
GroupMemberInfo
The group member info class, which contains the group member information.
LoginExtensionInfo
MessageCallBackManager
MessageSearchOptions
ReactionOperation
Reaction operation.
RecallMessageInfo

Enums

ChatConversationType
The conversation types.
ChatGroupPermissionType
The group roles.
ChatGroupStyle
The group types.
ChatMultiDevicesEvent
Multi-device event types.
ChatRoomMessagePriority
Chat room message priorities.
ChatRoomPermissionType
The chat room roles.
ChatSearchDirection
The message search directions.
ChatSilentModeParamType
The offline push settings.
ConversationMarkType
The conversation mark types.

Functions

convertIntToChatMultiDevicesEvent(int? i) ChatMultiDevicesEvent?
getAllMessageCount() Future<int>
Get the message count from db.
groupStyleTypeFromInt(int? type) ChatGroupStyle
groupStyleTypeToInt(ChatGroupStyle? type) int
loadConversationMessagesWithKeyword({String? keyword, int timestamp = -1, String? sender, ChatSearchDirection direction = ChatSearchDirection.Up, MessageSearchScope scope = MessageSearchScope.All}) Future<Map<String, List<String>>>
Loads messages with the specified keyword from the local database, returning a map containing conversation IDs and message ID arrays.

Typedefs

ChatError = ChatError
ChatEventHandle = ChatEventHandler
ChatManager = ChatManager
ChatPushRemindType = ChatPushRemindType
ChatRoom = ChatRoom
ChatRoomEventHandler = ChatRoomEventHandler
ChatSilentModeParam = ChatSilentModeParam
ChatSilentModeResult = ChatSilentModeResult
ChatThread = ChatThread
ChatThreadEvent = ChatThreadEvent
ChatThreadEventHandler = ChatThreadEventHandler
ChatThreadOperation = ChatThreadOperation
ChatType = ChatType
Client = ChatClient
CmdMessageBody = ChatCmdMessageBody
CombineMessageBody = CombineMessageBody
ConnectionEventHandler = ConnectionEventHandler
Contact = ChatContact
ContactEventHandler = ChatContactEventHandler
Conversation = ChatConversation
ConversationType = ChatConversationType
CursorResult<T> = ChatCursorResult<T>
CursorResultCallback = Object Function(dynamic obj)
CustomMessageBody = ChatCustomMessageBody
DisplayStyle = DisplayStyle
DownloadStatus = DownloadStatus
FetchMessageOptions = FetchMessageOptions
FileMessageBody = ChatFileMessageBody
Group = ChatGroup
GroupEventHandler = ChatGroupEventHandler
GroupInfo = ChatGroupInfo
GroupMessageAck = ChatGroupMessageAck
GroupOptions = ChatGroupOptions
GroupPermissionType = ChatGroupPermissionType
GroupSharedFile = ChatGroupSharedFile
GroupStyle = ChatGroupStyle
ImageMessageBody = ChatImageMessageBody
LeaveReason = LeaveReason
LocationMessageBody = ChatLocationMessageBody
Message = ChatMessage
MessageDirection = MessageDirection
MessageEvent = ChatMessageEvent
MessagePinInfo = MessagePinInfo
MessagePinOperation = MessagePinOperation
MessageReaction = ChatMessageReaction
MessageReactionEvent = ChatMessageReactionEvent
MessageSearchScope = MessageSearchScope
MessageStatus = MessageStatus
MessageType = MessageType
MultiDeviceEventHandler = ChatMultiDeviceEventHandler
MultiDevicesEvent = ChatMultiDevicesEvent
Options = ChatOptions
PageResult<T> = ChatPageResult<T>
PageResultCallback = Object Function(dynamic obj)
Presence = ChatPresence
PresenceEventHandler = ChatPresenceEventHandler
PushConfigs = ChatPushConfigs
ReactionOperate = ReactionOperate
RoomEventHandler = ChatRoomEventHandler
SearchDirection = ChatSearchDirection
TextMessageBody = ChatTextMessageBody
TranslateLanguage = ChatTranslateLanguage
UserInfo = ChatUserInfo
VideoMessageBody = ChatVideoMessageBody
VoiceMessageBody = ChatVoiceMessageBody