createTime property
int?
get
createTime
Gets the Unix timestamp for uploading the shared file, in milliseconds.
Return The Unix timestamp for uploading the shared file, in milliseconds.
Implementation
int? get createTime => _createTime;