sendOriginalImage property
Whether to send the original image.
- (default)
false: No. The original image will be compressed if it exceeds 100 KB and the thumbnail will be sent. true: Yes.
Implementation
bool sendOriginalImage = false;
Whether to send the original image.
false: No. The original image will be compressed if it exceeds 100 KB and the thumbnail will be sent.true: Yes.bool sendOriginalImage = false;