menu
agora_chat_uikit package
documentation
sdk_service/chat_sdk_service.dart
ChatMessage
to property
to property
dark_mode
light_mode
to
property
String
?
to
getter/setter pair
The message recipient.
For a one-to-one chat, it is the user ID of the peer user.
For a group chat, it is the group ID.
For a chat room, it is the chat room ID.
Implementation
String? to = '';
agora_chat_uikit package
documentation
sdk_service/chat_sdk_service
ChatMessage
to property
ChatMessage class