ChatPushConfigs class

The push configuration class.

Constructors

ChatPushConfigs({DisplayStyle displayStyle = DisplayStyle.Simple, String? displayName})
ChatPushConfigs.fromJson(Map map)
factory

Properties

displayName String?
The user's nickname to be displayed in the notification.
final
displayStyle → DisplayStyle
The display type of push notifications.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited