modifyCount property
int?
get
modifyCount
Gets the number of times a message is modified.
Implementation
int? get modifyCount => _operatorCount;
Gets the number of times a message is modified.
int? get modifyCount => _operatorCount;