MessageSearchOptions class
Properties
-
count
→ int
-
The number of messages to load, max 400.
final
-
direction
→ ChatSearchDirection
-
The message search direction.
final
-
from
→ String?
-
The message sender.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
ts
→ int
-
The message timestamp threshold for loading.
final
-
types
→ List<MessageType>
-
Message types list
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited