AndroidAudioMode enum

The audio mode encompasses audio routing AND the behavior of the telephony layer. Therefore this flag should only be used by applications that replace the platform-wide management of audio settings or the main telephony application. In particular, the inCall mode should only be used by the telephony application when it places a phone call, as it will cause signals from the radio layer to feed the platform mixer.

Inheritance
Available extensions

Values

normal → const AndroidAudioMode

Normal audio mode: not ringing and no call established.

const AndroidAudioMode(0)
ringtone → const AndroidAudioMode

Ringing audio mode. An incoming is being signaled.

const AndroidAudioMode(1)
inCall → const AndroidAudioMode

In call audio mode. A telephony call is established.

const AndroidAudioMode(2)
inCommunication → const AndroidAudioMode

In communication audio mode. An audio/video chat or VoIP call is established.

const AndroidAudioMode(3)
callScreening → const AndroidAudioMode

Call screening in progress. Call is connected and audio is accessible to call screening applications but other audio use cases are still possible.

const AndroidAudioMode(4)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<AndroidAudioMode>
A constant List of the values in this enum, in order of their declaration.