AssetSource class

Source representing the path of an application asset in your Flutter "assets" folder. Note that a prefix might be applied by your AudioPlayer's audio cache instance.

Inheritance

Constructors

AssetSource(String path, {String? mimeType})

Properties

hashCode → int
The hash code for this object.
no setterinherited
mimeType → String?
final
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setOnPlayer(AudioPlayer player) → Future<void>
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited