AudioContextAndroid class

A platform-specific class to encapsulate a collection of attributes about an Android audio stream.

Annotations

Constructors

AudioContextAndroid({bool isSpeakerphoneOn = false, AndroidAudioMode audioMode = AndroidAudioMode.normal, bool stayAwake = false, AndroidContentType contentType = AndroidContentType.music, AndroidUsageType usageType = AndroidUsageType.media, AndroidAudioFocus audioFocus = AndroidAudioFocus.gain})
const

Properties

audioFocus → AndroidAudioFocus
final
audioMode → AndroidAudioMode
Sets the audio mode, globally.
final
contentType → AndroidContentType
final
hashCode → int
The hash code for this object.
no setteroverride
isSpeakerphoneOn → bool
Sets the speakerphone on or off, globally.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stayAwake → bool
final
usageType → AndroidUsageType
final

Methods

copy({bool? isSpeakerphoneOn, AndroidAudioMode? audioMode, bool? stayAwake, AndroidContentType? contentType, AndroidUsageType? usageType, AndroidAudioFocus? audioFocus}) → AudioContextAndroid
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override