AudioLogLevel enum

Inheritance
Implemented types
Available extensions

Values

none → const AudioLogLevel
const AudioLogLevel(0)
error → const AudioLogLevel
const AudioLogLevel(1)
info → const AudioLogLevel
const AudioLogLevel(2)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
level → int
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(AudioLogLevel other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<AudioLogLevel>
A constant List of the values in this enum, in order of their declaration.