MapLocale class

Constructors

MapLocale(String languageCode, Map<String, dynamic> mapData, {String? countryCode, String? fontFamily, String? scriptCode})
Constructor of the model.
const

Properties

countryCode → String?
Country code is the region subtag for the locale.
final
fontFamily → String?
Font family for the language
final
hashCode → int
The hash code for this object.
no setterinherited
languageCode → String
Language code. This will use to check with the supported language codes and find the data for localization.
final
locale → Locale
Create a Locale object from MapLocale object
no setter
mapData → Map<String, dynamic>
This is the map of data that will use for localization.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptCode → String?
The script subtag for the locale.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited