PageAutoScrollController class

Inheritance
Mixed-in types

Constructors

PageAutoScrollController({int initialPage = 0, bool keepPage = true, double viewportFraction = 1.0, double? suggestedRowHeight, ViewportBoundaryGetter viewportBoundaryGetter = defaultViewportBoundaryGetter, AutoScrollController? copyTagsFrom, String? debugLabel})

Properties

beginGetter → AxisValueGetter
used to choose which direction you are using. e.g. axis == Axis.horizontal ? (r) => r.left : (r) => r.top
final
debugLabel → String?
A label that is used in the toString output. Intended to aid with identifying scroll controller instances in debug output.
finalinherited
endGetter → AxisValueGetter
final
hasClients → bool
Whether any ScrollPosition objects have attached themselves to the ScrollController using the attach method.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
hasParentController → bool
check if there is a parent controller
no setterinherited
initialPage → int
The page to show when first creating the PageView.
finalinherited
initialScrollOffset → double
The initial value to use for offset.
no setterinherited
isAutoScrolling → bool
detect if it's in scrolling (scrolling is a async process)
no setterinherited
keepPage → bool
Save the current page with PageStorage and restore it if this controller's scrollable is recreated.
finalinherited
keepScrollOffset → bool
Each time a scroll completes, save the current scroll offset with PageStorage and restore it if this controller's scrollable is recreated.
finalinherited
offset → double
The current scroll offset of the scrollable widget.
no setterinherited
onAttach → ScrollControllerCallback?
Called when a ScrollPosition is attached to the scroll controller.
finalinherited
onDetach → ScrollControllerCallback?
Called when a ScrollPosition is detached from the scroll controller.
finalinherited
page → double?
The current page displayed in the controlled PageView.
no setterinherited
parentController ← ScrollController
used to chaining parent scroll controller
no getterinherited
position → ScrollPosition
Returns the attached ScrollPosition, from which the actual scroll offset of the ScrollView can be obtained.
no setterinherited
positions → Iterable<ScrollPosition>
The currently attached positions.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestedRowHeight → double?
used to quick scroll to a index if the row height is the same
final
tagMap → Map<int, AutoScrollTagState<AutoScrollTag>>
all layout out states will be put into this map
finalinherited
viewportBoundaryGetter → ViewportBoundaryGetter
used to make the additional boundary for viewport e.g. a sticky header which covers the real viewport of a list view
final
viewportFraction → double
The fraction of the viewport that each page should occupy.
finalinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
animateTo(double offset, {required Duration duration, required Curve curve}) → Future<void>
Animates the position from its current value to the given value.
inherited
animateToPage(int page, {required Duration duration, required Curve curve}) → Future<void>
Animates the controlled PageView from the current page to the given page.
inherited
attach(ScrollPosition position) → void
Register the given position with this controller.
inherited
cancelAllHighlights() → void
cancel all highlight item immediately.
inherited
createScrollPosition(ScrollPhysics physics, ScrollContext context, ScrollPosition? oldPosition) → ScrollPosition
Creates a ScrollPosition for use by a Scrollable widget.
inherited
debugFillDescription(List<String> description) → void
Add additional information to the given description for use by toString.
inherited
detach(ScrollPosition position) → void
Unregister the given position with this controller.
inherited
dispose() → void
Discards any resources used by the object.
inherited
highlight(int index, {bool cancelExistHighlights = true, Duration highlightDuration = _highlightDuration, bool animated = true}) → Future
highlight the item
inherited
isIndexStateInLayoutRange(int index) → bool
check if the state is created. that is, is the indexed widget is layout out. NOTE: state created doesn't mean it's in viewport. it could be a buffer range, depending on flutter's implementation.
inherited
jumpTo(double value) → void
Jumps the scroll position from its current value to the given value, without animation, and without checking if the new value is in range.
inherited
jumpToPage(int page) → void
Changes which page is displayed in the controlled PageView.
inherited
nextPage({required Duration duration, required Curve curve}) → Future<void>
Animates the controlled PageView to the next page.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
previousPage({required Duration duration, required Curve curve}) → Future<void>
Animates the controlled PageView to the previous page.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
scrollToIndex(int index, {Duration duration = scrollAnimationDuration, AutoScrollPosition? preferPosition}) → Future
scroll to the giving index
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited