TimerPositionUpdater class

Inheritance

Constructors

TimerPositionUpdater({required Future<Duration?> getPosition(), required Duration interval})
Position stream will be updated in the according interval.

Properties

getPosition → Future<Duration?> Function()
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
interval → Duration
final
positionStream → Stream<Duration>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
override
stop() → void
override
stopAndUpdate() → Future<void>
inherited
toString() → String
A string representation of this object.
inherited
update() → Future<void>
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited